<?php
/**
 * @version		1.0.0
 * @package		Joomla
 * @subpackage	OSMap - EShop
 * @author  	Giang Dinh Truong
 * @copyright	Copyright (C) 2012 Ossolution Team
 * @license		GNU/GPL, see LICENSE.php
 */

defined('_JEXEC') or die('Restricted access');

require_once JPATH_SITE . '/components/com_osmap/helpers/osmap.php';
require_once JPATH_ADMINISTRATOR . '/components/com_eshop/libraries/autoload.php';

class osmap_com_eshop {
	
    public static $urlBase;

    public static function getTree($osmap, $parent, &$params) {

        $app  = JFactory::getApplication();
        $menu = $app->getMenu();

        $catid='-1';
        $link_query = parse_url( $parent->link );
        parse_str( html_entity_decode($link_query['query']), $link_vars);
        $params['Itemid'] = intval(osmap_com_eshop::getParam($link_vars, 'Itemid', $parent->id));

        if (strpos($parent->link, 'view=frontpage') || strpos($parent->link, 'view=categories') || strpos($parent->link, 'view=category')) {
            $catid = osmap_com_eshop::getParam($link_vars, 'id', 0);
        }

        $view = osmap_com_eshop::getParam($link_vars, 'view', 'frontpage');

        if (!in_array($view, array('frontpage', 'categories', 'category'))) {
            return true;
        }

        $include_products = osmap_com_eshop::getParam($params, 'include_products', 1);
        $include_products = ( $include_products == 1
            || ($include_products == 2 && $osmap->view == 'xml')
            || ($include_products == 3 && $osmap->view == 'html')
            || $osmap->view == 'navigator'
        );

        $params['include_products']          = $include_products;
        $params['include_product_images']    = (osmap_com_eshop::getParam($params, 'include_product_images', 1)
            && $osmap->view == 'xml');
        $params['product_image_license_url'] = trim(osmap_com_eshop::getParam($params, 'product_image_license_url', ''));

        $priority   = osmap_com_eshop::getParam($params, 'cat_priority', $parent->priority);
        $changefreq = osmap_com_eshop::getParam($params, 'cat_changefreq', $parent->changefreq);

        if ($priority == '-1') {
            $priority = $parent->priority;
        }

        if ($changefreq == '-1') {
            $changefreq = $parent->changefreq;
        }

        $params['cat_priority']   = $priority;
        $params['cat_changefreq'] = $changefreq;

        $priority   = osmap_com_eshop::getParam($params, 'product_priority', $parent->priority);
        $changefreq = osmap_com_eshop::getParam($params, 'product_changefreq', $parent->changefreq);

        if ($priority == '-1') {
            $priority = $parent->priority;
        }

        if ($changefreq == '-1') {
            $changefreq = $parent->changefreq;
        }

        $params['product_priority']   = $priority;
        $params['product_changefreq'] = $changefreq;
		
        $ordering = osmap_com_eshop::getParam($params, 'cats_order', 'ordering');
        $orderdir = osmap_com_eshop::getParam($params, 'cats_orderdir', 'ASC');
        if ( !in_array($ordering, array('ordering', 'name', 'modified', 'created', 'hits')) )
            $ordering = 'ordering';
            
        if ( !in_array($orderdir,array('ASC','DESC')) ){
            $orderdir = 'ASC';
        }

        $params['cats_order'] = "`$ordering` $orderdir";

        if ( $include_products ) {
            $ordering = osmap_com_eshop::getParam($params, 'products_order', 'ordering');
            $orderdir = osmap_com_eshop::getParam($params, 'products_orderdir', 'ASC');
            if ( !in_array($ordering, array('ordering', 'name', 'modified', 'created', 'hits')) )
                $ordering = 'ordering';
            
            if ( !in_array($orderdir,array('ASC','DESC')) ){
                $orderdir = 'ASC';
            }

            $params['products_order'] = "`$ordering` $orderdir";

            $params['limit'] = '';
            $params['days'] = '';
            $limit = osmap_com_eshop::getParam($params, 'max_products', 0);
            if ( intval($limit) )
                $params['limit'] = ' LIMIT '.intval($limit);

            $days = osmap_com_eshop::getParam($params, 'max_age', '');
            if ( intval($days) )
                $params['days'] = ' AND i.`created` >=\''.date('Y-m-d H:i:s',($osmap->now - ($days*86400))) ."' ";
        }

        self::getCategoryTree($osmap, $parent, $params, $catid);

        return true;
    }

    public static function getCategoryTree($osmap, $parent, &$params, $catid = 0) {
        if (!isset($urlBase)) {
            $urlBase = JURI::base();
        }
		
		$lang_tag = JFactory::getLanguage()->getTag();
		
        $database = JFactory::getDBO();

        $query = "SELECT c.id AS cat_id, d.category_name, c.created_date AS `created`, c.modified_date AS `modified`, c.hits".
                " FROM #__eshop_categories AS c, #__eshop_categorydetails AS d".
				" WHERE c.id = d.category_id AND c.published = '1' AND c.category_parent_id = '{$catid}' AND d.language = '{$lang_tag}' GROUP BY d.category_id ORDER BY " . $params['cats_order'] .'';
        
		$database->setQuery($query);
        $children = $database->loadObjectList();

        $osmap->changeLevel(1);
		
        if (!empty($children)) {

            foreach ($children as $row) {
                $node = new stdclass;

                $node->id         = $parent->id;
                $node->uid        = $parent->uid .'c'. $row->cat_id;
                $node->browserNav = $parent->browserNav;
                $node->name       = stripslashes($row->category_name);
                $node->priority   = $params['cat_priority'];
                $node->changefreq = $params['cat_changefreq'];
                $node->expandible = true;
                //$node->link       = 'index.php?option=com_eshop&view=category&id='.$row->cat_id. '&Itemid='.$parent->id;
                $node->link       = EshopRoute::getCategoryRoute($row->cat_id);

                if ($osmap->printNode($node) !== FALSE) {
                    self::getCategoryTree($osmap, $parent, $params, $row->cat_id);
                }
            }
        }

        if ($params['include_products'] && $catid != 0) {
			
            $query = " SELECT DISTINCT p.id, d.product_name, p.created_date AS `created`, p.modified_date AS `modified`, p.hits, c.category_id".
                " FROM #__eshop_products AS p, #__eshop_productdetails AS d, #__eshop_productcategories as c".
				" WHERE p.id = d.product_id AND  p.id = c.product_id AND c.category_id = '{$catid}' AND p.published = '1' AND d.language = '{$lang_tag}'".
                $params['days'] ." ORDER BY " .$params['products_order'] .$params['limit'];

            $database->setQuery($query);
            $products = $database->loadObjectList();

            foreach ($products as $product) {
                $node = new stdclass;

                $node->id         = $parent->id;
                $node->uid        = $parent->uid . 'c' . $product->category_id . 'i' . $product->id;
                $node->browserNav = $parent->browserNav;
                $node->priority   = $params['product_priority'];
                $node->changefreq = $params['product_changefreq'];
                $node->name       = $product->product_name;
                $node->modified   = ($product->modified ? $product->modified : $product->created);
                $node->expandible = false;
                //$node->link       = 'index.php?option=com_eshop&view=product&id='.$product->id.'&catid='.$product->category_id. '&Itemid='.$parent->id;
                $node->link       = EshopRoute::getProductRoute($product->id, $product->category_id);

                if ($params['include_product_images']) {
					
					$query = " SELECT image FROM #__eshop_productimages WHERE product_id = '{$product->id}' AND published = '1'";
					$database->setQuery($query);
					$images = $database->loadObjectList();

                    foreach($images AS $image){
						$imagenode = new stdClass;

						$imagenode->src     = $urlBase . 'media/com_eshop/products/'. $image->image;
						$imagenode->title   = $product->product_name;
						$imagenode->license = $params['product_image_license_url'];

						$node->images[] = $imagenode;
                    }
                }

                $osmap->printNode($node);
            }
        }

        $osmap->changeLevel(-1);
    }

    static function getParam($arr, $name, $def)
    {
        $var = JArrayHelper::getValue( $arr, $name, $def, '' );
        return $var;
    }
}